﻿Collapsor = function(elements, settings, callback) {
    this.settings = $.extend({}, Collapsor.defaultSettings, settings);
    this.callback = callback;
    this.trigger = elements.trigger;
    this.mainPanel = elements.mainPanel;
    this.resizablePanel = elements.resizablePanel;
    
    this.init();
};

Collapsor.prototype = {

    init : function() {
        $(this.trigger).bind('click', Function.createDelegate(this, this.triggerClickHandler));
        this.update(this.getExpanded());
    },

    expand: function() {
        $(this.trigger).addClass(this.settings.expandedLinkClass);
        $(this.trigger).removeClass(this.settings.collapsedLinkClass);
        $(this.resizablePanel).show();
        if (this.settings.dividerLocation) {
            $(this.mainPanel).css({ width: this.settings.dividerLocation + 'px' });
        }
    },

    collapse: function() {
        $(this.trigger).addClass(this.settings.collapsedLinkClass);
        $(this.trigger).removeClass(this.settings.expandedLinkClass);
        $(this.resizablePanel).hide();
        if (this.settings.dividerLocation) {
            $(this.mainPanel).css({ width: '' });
        }
    },

    update: function(value) {
        if (value) {
            this.expand();            
        }
        else {
            this.collapse();
        }
        if (this.callback) {
            this.callback.call(this);
        }
    },

    getExpanded: function() {
        if (this.settings.saveState) {
            cookieValue = $.cookie(this.settings.key);
            if (!cookieValue) {
                cookieValue = this.settings.isExpanded;
            }
            else {
                cookieValue = Boolean.parse(cookieValue);
            }
            return cookieValue;
        }
        else {
            return this.settings.isExpanded;
        }
    },

    setExpanded: function(value) {    
        if (typeof value != 'boolean') {
            value = true;
        }
        if (this.settings.saveState) {
            $.cookie(this.settings.key, value, { path: '/', expires: 10 });
        }
        else {
            this.settings.isExpanded = value;
        }
        this.update(value);
    },

    triggerClickHandler: function() {
        this.setExpanded(!this.getExpanded());
    }
};

Collapsor.defaultSettings = {
    collapsedLinkClass: '',
    expandedLinkClass: '',
    isExpanded: true,
    key : 'collapsable-state',
    saveState: true
};

(function($) {

	$.fn.makeCollapsable = function(elements, settings, callback) {
	    return this.each(function() {
		    new Collapsor($.extend({}, {trigger: this}, elements), settings, callback);
	    });
	};

})(jQuery);