MainMenu = function(groupsContainer, groups, itemsContainer, itemsHeader, activeModule, settings) {
	this.groupsContainer = groupsContainer;
	this.groups = groups;
	this.itemsContainer = itemsContainer;
	this.itemsHeader = itemsHeader;
	this.settings = $.extend({}, MainMenu.defaults, settings);
	
	this.activeModule = activeModule;
	this.activeGroup = null;
	this.initializeGroups();
	this.initializeItems();
}

MainMenu.defaults = {
	activeGroupKey : 'main-menu-active-group',
	groups : 'li',
	items : 'li',
	activeGroupClass : 'active',
	activeItemClass : 'active',
	serviceUrl : 'http://localhost/Core2/Admin/MenuSubItemsHandler.aspx'
}

MainMenu.prototype = {

	getActiveGroup : function() {
		if (this.activeGroup == null) {
			this.activeGroup = parseInt($.cookie(this.settings.activeGroupKey));
			if (isNaN(this.activeGroup)) {
				this.activeGroup = 0;
			}
		}
		return this.activeGroup;
	},
	
	setActiveGroup : function(activeGroup) {
		this.activeGroup = activeGroup;
		$.cookie(this.settings.activeGroupKey, activeGroup, { path: '/', expires: 10 });
	},
	
	getActiveGroupID : function() {
		activeGroupID = 0;
		activeGroup = this.getActiveGroup();		
		if (activeGroup >= 0 && activeGroup < this.groups.length) {
			activeGroupID = this.groups[activeGroup];
		}
		return activeGroupID;
	},

	initializeGroups : function() {
		menu = this;
		activeGroup = this.getActiveGroup();
		currentIndex = 0;	
		$(menu.settings.groups, menu.groupsContainer).each(function() {
			$(this).bind('click', Function.createCallback(menu.groupClickHandler, {menu: menu, group: currentIndex}));        
			$(this).hover(
				function () {
					$(this).addClass('over');
				}, 
				function () {
					$(this).removeClass('over');
				}
			);
			if (activeGroup == currentIndex) {
				$(this).addClass(menu.settings.activeGroupClass);
			}
			currentIndex++;
		});				
	},
	
	groupClickHandler : function(e, context) {	    
		menu = context.menu;
		if (context.group != menu.getActiveGroup()) {
		    menu.setActiveGroup(context.group);
		    $(menu.settings.groups, menu.groupsContainer).removeClass(menu.settings.activeGroupClass);
		    $(this).addClass(menu.settings.activeGroupClass);
		    menu.initializeItems();
		    $(menu).change();
		}
	},
	
	initializeItems : function() {
		$.getMSJSON(this.settings.serviceUrl, 
			{groupID : this.getActiveGroupID()}, 
			Function.createDelegate(this, this.getItemsCallback),
			Function.createDelegate(this, this.errorRequestHandler), 
			'POST');
	},
	
	getItemsCallback : function(response, result) {
	    if (response) {
	        $(this.itemsHeader).html(response.Group.Title);
		    ul = $.create('ul');
		    $(this.itemsContainer).empty().append(ul);
		    for (i in response.Items) {
			    menuItem = response.Items[i];
			    li = $.create('li', {}, [
						    link = $.create('a', { href : menuItem.url }, [menuItem.moduleTitle])
					    ]).appendTo(ul);
			    if (menuItem.moduleID == this.activeModule) {
				    link.addClass(this.settings.activeItemClass);
			    }
		    }
		}
	},
	
	errorRequestHandler : function(response, result) {
		$.log('WARN', response.responseText);
	}
}